@@ -10,13 +10,6 @@ from chalk.utils.missing_dependency import missing_dependency_exception
 if TYPE_CHECKING:
     import polars as pl
 
-try:
-    import duckdb
-    import sqlglot
-except ModuleNotFoundError:
-    duckdb = None
-    sqlglot = None
-
 from chalk.utils.string import normalize_string_for_matching
 
 
@@ -35,10 +28,13 @@ def _resolve_implicit_col_feature_mappings_str(
 
 
 def query_arrow_table(query: str, table: pa.Table) -> pa.Table:
-    if duckdb is None or sqlglot is None:
+    try:
+        import duckdb
+        import sqlglot
+        import sqlglot.expressions
+    except ModuleNotFoundError:
         raise missing_dependency_exception("chalkpy[runtime]")
-    t: sqlglot.exp.Table
-    table_names = list({t.name for t in sqlglot.parse_one(query).find_all(sqlglot.exp.Table)})
+    table_names = list({t.name for t in sqlglot.parse_one(query).find_all(sqlglot.expressions.Table)})
     con = duckdb.connect(database=":memory:")
     if len(table_names) > 1:
         raise ValueError(f"Query should target only one table. Found: {', '.join(table_names)}")
@@ -67,10 +63,10 @@ def query_as_features(
         expected_features=fqn_to_name.values(),
     )
     name_to_fqn = {v: k for k, v in fqn_to_name.items()}
-    renamed = (
-        pl.from_arrow(res)
-        .drop([col for col, f in zip(res.column_names, col_feature_mappings) if f is None])
-        .rename({col: name_to_fqn[f] for col, f in zip(res.column_names, col_feature_mappings) if f is not None})
+    df = pl.from_arrow(res)
+    assert isinstance(df, pl.DataFrame)
+    renamed = df.drop([col for col, f in zip(res.column_names, col_feature_mappings) if f is None]).rename(
+        {col: name_to_fqn[f] for col, f in zip(res.column_names, col_feature_mappings) if f is not None}
     )
     return renamed
 
