@@ -9,8 +9,8 @@ from typing import List, Optional
 
 from pydantic import ValidationError
 
-from chalk import importer
-from chalk.config.project_config import ProjectSettings, load_project_config
+from chalk.config.project_config import load_project_config
+from chalk.importer import import_all_files
 from chalk.parsed.user_types_to_json import get_registered_types_as_json
 from chalk.utils.stubgen import configure_stubgen_argparse, run_stubgen
 
@@ -18,7 +18,7 @@ from chalk.utils.stubgen import configure_stubgen_argparse, run_stubgen
 def _get_list_results(directory: Optional[str]):
     scope_to = Path(directory or os.getcwd())
     try:
-        failed = importer._import_all_files()
+        failed = import_all_files()
         return get_registered_types_as_json(scope_to, failed)
     except Exception:
         ex_type, ex_value, ex_traceback = sys.exc_info()
@@ -41,10 +41,14 @@ def list_cmd(directory: str):
 def config_cmd():
     json_response: str
     try:
-        model = load_project_config() or ProjectSettings()
-        json_response = model.json()
+        model = load_project_config()
     except ValidationError as e:
         json_response = json.dumps({"error": str(e)})
+    else:
+        if model is None:
+            print("No `chalk.yaml` configuration file found")
+            return
+        json_response = model.json()
 
     print(json_response)
 
@@ -89,8 +93,9 @@ def cli(args_override: Optional[List[str]] = None):
         dump_cmd(args.filename, args.directory)
     else:
         parser.print_help(sys.stderr)
-        sys.exit(1)
+        return 1
+    return 0
 
 
 if __name__ == "__main__":
-    cli()
+    sys.exit(cli())
