@@ -186,6 +186,9 @@ class OnlineQueryResponseImpl(OnlineQueryResult):
     def __repr__(self) -> str:
         return repr(self._df_repr())
 
+    def __str__(self):
+        return str(self._df_repr())
+
     def _repr_html_(self) -> Union[str, None]:
         return self._df_repr()._repr_html_()
 
@@ -424,6 +427,7 @@ class ChalkAPIClientImpl(ChalkClient):
 
         outputs: List[str] = [str(feature) for feature in output]
 
+        branch = branch or self._config.branch
         request = OnlineQueryRequest(
             inputs=encoded_inputs,
             outputs=outputs,
@@ -433,6 +437,7 @@ class ChalkAPIClientImpl(ChalkClient):
                 tags=tags,
             ),
             deployment_id=preview_deployment_id,
+            branch_id=branch,
             correlation_id=correlation_id,
             query_name=query_name,
             meta=meta,
@@ -448,7 +453,11 @@ class ChalkAPIClientImpl(ChalkClient):
             preview_deployment_id=preview_deployment_id,
             branch=branch,
         )
-        return OnlineQueryResponseImpl(data=resp.data, errors=resp.errors or [], warnings=encoding_warnings)
+        return OnlineQueryResponseImpl(
+            data=resp.data,
+            errors=resp.errors or [],
+            warnings=encoding_warnings,
+        )
 
     def offline_query(
         self,
