@@ -29,6 +29,12 @@ _TPrimCo = TypeVar("_TPrimCo", bound=TPrimitive, covariant=True)
 _TPrimCon = TypeVar("_TPrimCon", bound=TPrimitive, contravariant=True)
 
 
+class MissingValueError(TypeError):
+    """Raised when a missing value is encountered and the missing value strategy is set to ``error``."""
+
+    pass
+
+
 class TEncoder(Protocol[_TPrimCo, _TRichCon]):
     def __call__(self, value: _TRichCon, /) -> _TPrimCo:
         ...
@@ -194,7 +200,7 @@ class FeatureConverter(Generic[_TPrim, _TRich]):
                     )
                     return cast(_TPrim, value)
             elif missing_value_strategy == "error":
-                raise TypeError(
+                raise MissingValueError(
                     f"The value for feature '{self._name}' is missing, but `replace_missing_with_defaults` was set to False."
                 )
             else:
