@@ -4,7 +4,7 @@ import dataclasses
 import decimal
 import enum
 from datetime import date, datetime, time, timedelta
-from typing import TYPE_CHECKING, Dict, FrozenSet, List, Set, Tuple, Type, TypedDict, cast
+from typing import TYPE_CHECKING, Dict, FrozenSet, List, Set, Tuple, Type, TypedDict, Union, cast
 
 import attrs
 import pyarrow as pa
@@ -141,9 +141,11 @@ def pyarrow_to_primitive(pyarrow_typ: pa.DataType, name: str) -> Type[TPrimitive
     if pa.types.is_string(pyarrow_typ) or pa.types.is_large_string(pyarrow_typ):
         return cast(Type[TPrimitive], str)
     if pa.types.is_list(pyarrow_typ) or pa.types.is_large_list(pyarrow_typ) or pa.types.is_fixed_size_list(pyarrow_typ):
+        pyarrow_typ = cast(Union[pa.ListType, pa.LargeListType, pa.FixedSizeListType], pyarrow_typ)
         underlying = pyarrow_typ.value_type
         return cast(Type[TPrimitive], List[pyarrow_to_primitive(underlying, name=f"{name}[]")])
     if pa.types.is_struct(pyarrow_typ):
+        pyarrow_typ = cast(pa.StructType, pyarrow_typ)
         # Dynamically making a TypedDict so members will be parsed with the correct types by cattrs
         annotations: Dict[str, Type[TPrimitive]] = {}
         schema = pa.schema(pyarrow_typ)
@@ -194,19 +196,25 @@ def pyarrow_to_polars(pa_type: pa.DataType, name: str) -> pl.PolarsDataType:
     if pa.types.is_time(pa_type):
         return pl.Time()
     if pa.types.is_timestamp(pa_type):
+        pa_type = cast(pa.TimestampType, pa_type)
+        assert pa_type.unit in ("ms", "us", "ns")
         return pl.Datetime(pa_type.unit, pa_type.tz)
     if pa.types.is_date(pa_type):
         return pl.Date()
     if pa.types.is_duration(pa_type):
-        return pl.Duration()
+        pa_type = cast(pa.DurationType, pa_type)
+        assert pa_type.unit in ("ms", "us", "ns")
+        return pl.Duration(pa_type.unit)
     if pa.types.is_binary(pa_type) or pa.types.is_fixed_size_binary(pa_type) or pa.types.is_large_binary(pa_type):
         return pl.Binary()
     if pa.types.is_string(pa_type) or pa.types.is_large_string(pa_type):
         return pl.Utf8()
     if pa.types.is_list(pa_type) or pa.types.is_large_list(pa_type) or pa.types.is_fixed_size_list(pa_type):
+        pa_type = cast(Union[pa.ListType, pa.LargeListType, pa.FixedSizeListType], pa_type)
         underlying = pa_type.value_type
         return pl.List(pyarrow_to_polars(underlying, name=f"{name}[]"))
     if pa.types.is_struct(pa_type):
+        pa_type = cast(pa.StructType, pa_type)
         schema = pa.schema(pa_type)
 
         fields = [
