@@ -3,6 +3,7 @@ from __future__ import annotations
 import base64
 import collections.abc
 import inspect
+import itertools
 import json
 import operator
 import os
@@ -15,6 +16,7 @@ from typing import (
     Callable,
     ClassVar,
     Dict,
+    Iterable,
     List,
     Literal,
     Mapping,
@@ -360,7 +362,7 @@ class DataFrameImpl(metaclass=DataFrameMeta):
         # By default, data should match the dtype of the feature.
         # However, when doing comparisons, data will be converted to bools,
         # in which case the data types should no longer be converted.
-        # This is an undocumented parameters so it does not appear in the docstring
+        # This is an undocumented parameter, so it does not appear in the docstring
         convert_dtypes: bool = True,
         pydantic_model: Optional[Type[BaseModel]] = None,
     ):
@@ -769,15 +771,15 @@ class DataFrameImpl(metaclass=DataFrameMeta):
             raise missing_dependency_exception("chalkpy[runtime]")
 
         data = None
-        if (
-            (type(path) == "string" and path.startswith("s3"))
-            or (type(path) == "PosixPath")
-            and (str(path).startswith("s3"))
-        ):
+        if isinstance(path, str) and path.startswith("s3://"):
             try:
                 import fsspec
             except ImportError:
                 raise missing_dependency_exception("fsspec")
+            try:
+                import s3fs
+            except ImportError:
+                raise missing_dependency_exception("s3fs")
             try:
                 import io
             except ImportError:
@@ -871,6 +873,57 @@ class DataFrameImpl(metaclass=DataFrameMeta):
             "The dataframe contains multiple items. DataFrame.item() can only be used if the dataframe has a single element."
         )
 
+    def sort(
+        self,
+        by: Union[str, Feature, Any, Iterable[str, Feature, Any]],
+        *more_by: Union[str, Feature, Any],
+        descending: Union[bool, Sequence[bool]] = False,
+        nulls_last: bool = False,
+    ) -> DataFrame:
+        """
+        Sort the dataframe by the given columns.
+
+        Parameters
+        ----------
+        by
+            Feature(s) to sort by. Strings are parsed as feature names.
+        more_by
+            Additional columns to sort by, specified as positional arguments.
+        descending
+            Sort in descending order. When sorting by multiple columns,
+            can be specified per feature by passing a sequence of booleans.
+        nulls_last
+            Place null values last.
+
+        Returns
+        -------
+        DataFrame
+            A new dataframe with the rows sorted.
+
+        Examples
+        --------
+        >>> df = DataFrame({
+        ...     User.a: [1, 2, 3],
+        ...     User.b: [3, 2, 1],
+        ... })
+        >>> df.sort(User.a)
+              a  b
+        -----------
+        0     1  3
+        1     2  2
+        2     3  1
+        """
+        by = tuple(str(x) for x in itertools.chain(ensure_tuple(by), more_by))
+        return DataFrame(
+            self._underlying.sort(
+                by=by,
+                reverse=descending,
+                nulls_last=nulls_last,
+            ),
+            convert_dtypes=False,
+            pydantic_model=self._pydantic_model,
+        )
+
     def __bool__(self):
         if self.shape == (1, 1):
             # It's a dataframe of 1 item. self.any() and self.all() would return the same thing
@@ -1126,6 +1179,19 @@ class DataFrameImpl(metaclass=DataFrameMeta):
         -------
 
         """
+        if isinstance(item, int) and not isinstance(item, bool):
+            if item >= 0:
+                underlying = self._underlying.head(item + 1).tail(1)
+            else:
+                underlying = self._underlying.tail(-item).head(1)
+
+            df = DataFrame(
+                underlying,
+                convert_dtypes=False,
+                pydantic_model=self._pydantic_model,
+            )
+            return list(df.to_features())[0]
+
         has_bool_or_filter_value = any(isinstance(x, (bool, Filter)) for x in ensure_tuple(item))
         if has_bool_or_filter_value:
             # If we have a boolean or Filter value, then that means we need to ast-parse the caller since
