@@ -297,6 +297,15 @@ def _get_field(
         if f.version is not None:
             f.version.base_name = f._name or annotation_name
             f.name = f.version.name_for_version(f.version.default)
+        if f.is_name_set():
+            if "." in f.name:
+                raise ValueError(
+                    f"Custom feature names cannot contain a dot, but the feature '{f.name}' on the class '{cls.__name__}' includes a dot. You might consider using a has-one feature instead."
+                )
+            elif " " in f.name:
+                raise ValueError(
+                    f"Custom feature names cannot contain spaces, but the feature '{f.name}' on the class '{cls.__name__}' includes a space."
+                )
     elif isinstance(default, Windowed):
         # The feature was set like x: Windowed[int] = windowed()
         # Convert it to a Feature
@@ -421,12 +430,12 @@ def _repr_fn(_globals: Dict[str, Any]):
 
 
 def _eq_fn(_globals: Dict[str, Any]):
-    cmp_str = "all(getattr(self, f.attribute_name, MISSING) == getattr(other, f.attribute_name, MISSING) for f in self.features)"
+    cmp_str = "all(getattr(self, f.attribute_name, MISSING) == getattr(__chalk_other__, f.attribute_name, MISSING) for f in self.features)"
     return create_fn(
         name="__eq__",
-        args=["self", "other"],
+        args=["self", "__chalk_other__"],
         body=[
-            "if not isinstance(other, type(self)):",
+            "if not isinstance(__chalk_other__, type(self)):",
             "    return NotImplemented",
             f"return {cmp_str}",
         ],
@@ -442,11 +451,25 @@ def _len_fn(_globals: Dict[str, Any]):
         name="__len__",
         args=["self"],
         body=[
-            "count = 0",
-            f"for f in self.features:",
-            "    if not f.no_display and hasattr(self, f.attribute_name):",
-            "        count += 1",
-            "return count",
+            "__chalk_count__ = 0",
+            f"for __chalk_f__ in self.features:",
+            "    if not __chalk_f__.no_display and hasattr(self, __chalk_f__.attribute_name):",
+            "        __chalk_count__ += 1",
+            "return __chalk_count__",
+        ],
+        _globals=_globals,
+        _locals={},
+    )
+
+
+def _items_fn(_globals: Dict[str, Any]):
+    return create_fn(
+        name="items",
+        args=["self"],
+        body=[
+            f"for __chalk_f__ in self.features:",
+            "    if not __chalk_f__.no_display and hasattr(self, __chalk_f__.attribute_name):",
+            "        yield __chalk_f__.fqn, getattr(self, __chalk_f__.attribute_name)",
         ],
         _globals=_globals,
         _locals={},
@@ -639,6 +662,7 @@ def _process_class(
     set_new_attribute(cls=cls, name="__eq__", value=_eq_fn(_globals=_globals))
     set_new_attribute(cls=cls, name="__hash__", value=None)
     set_new_attribute(cls=cls, name="__iter__", value=_iter_fn(_globals=_globals))
+    set_new_attribute(cls=cls, name="items", value=_items_fn(_globals=_globals))
 
     set_new_attribute(cls=cls, name="namespace", value=namespace)
     set_new_attribute(cls=cls, name="__chalk_namespace__", value=namespace)
