@@ -1,6 +1,6 @@
 import collections
 from collections import defaultdict
-from typing import Dict, List, Mapping, NewType
+from typing import Dict, List, Mapping
 
 from chalk.parsed.duplicate_input_gql import (
     GraphLogSeverity,
@@ -46,8 +46,10 @@ def _validate_primary_key(feature: UpsertFeatureGQL, builder: _LogBuilder):
     ):
         builder.add_error(
             header=f'Invalid primary key type "{feature.id.fqn}"',
-            subheader=f"Primary keys must be integers or strings. "
-            f'Feature "{feature.id.fqn}" has a type of {feature.scalarKind.scalarKind}',
+            subheader=(
+                f"Primary keys must be integers or strings. "
+                f'Feature "{feature.id.fqn}" has a type of {feature.scalarKind.scalarKind}'
+            ),
         )
 
 
@@ -84,11 +86,13 @@ def _validate_no_feature_times_as_input(
         elif fqn_to_feature[i.underlying.fqn].featureTimeKind is not None and resolver.kind != "offline":
             builder.add_error(
                 header=f"Feature times cannot be accepted as input to {resolver.kind} resolvers.",
-                subheader=f'The resolver "{resolver.fqn}" takes as input the\n'
-                f'feature "{i.underlying.fqn}", a feature_time() type.\n'
-                f"Feature times can be returned from {resolver.kind} resolvers to\n"
-                "indicate data from the past, but cannot be accepted\n"
-                "as inputs.",
+                subheader=(
+                    f'The resolver "{resolver.fqn}" takes as input the\n'
+                    f'feature "{i.underlying.fqn}", a feature_time() type.\n'
+                    f"Feature times can be returned from {resolver.kind} resolvers to\n"
+                    "indicate data from the past, but cannot be accepted\n"
+                    "as inputs."
+                ),
             )
 
 
@@ -101,8 +105,10 @@ def _validate_feature_names_unique(features: List[UpsertFeatureGQL], builder: _L
         if count > 1:
             builder.add_error(
                 header="Duplicate feature names",
-                subheader=f'There are {count} features with the same name of "{fqn}". All features require a '
-                f"distinct name",
+                subheader=(
+                    f'There are {count} features with the same name of "{fqn}". All features require a '
+                    f"distinct name"
+                ),
             )
 
 
@@ -115,8 +121,10 @@ def _validate_resolver_names_unique(resolvers: List[UpsertResolverGQL], builder:
         if count > 1:
             builder.add_error(
                 header="Duplicate resolver names",
-                subheader=f'There are {count} resolvers with the same name of "{name}". All resolvers require a '
-                f"distinct name",
+                subheader=(
+                    f'There are {count} resolvers with the same name of "{name}". All resolvers require a '
+                    f"distinct name"
+                ),
             )
 
 
@@ -214,14 +222,18 @@ def _validate_feature_names(feature: UpsertFeatureGQL, builder: _LogBuilder):
     if feature.id.name.startswith("__") or feature.id.name.startswith("_chalk"):
         builder.add_error(
             header="Feature uses protected name",
-            subheader=f'The feature "{feature.id.fqn}" uses the protected name "{feature.id.name}". '
-            'Feature names cannot begin with "_chalk" or "__". Please rename this feature.',
+            subheader=(
+                f'The feature "{feature.id.fqn}" uses the protected name "{feature.id.name}". '
+                'Feature names cannot begin with "_chalk" or "__". Please rename this feature.'
+            ),
         )
     if feature.id.namespace.startswith("__") or feature.id.name.startswith("_chalk"):
         builder.add_error(
             header="Feature class uses protected namespace",
-            subheader=f'The feature "{feature.id.fqn}" belongs to the protected namespace "{feature.id.namespace}". '
-            f'Feature namespaces cannot begin with "_chalk" or "__". Please rename this feature set.',
+            subheader=(
+                f'The feature "{feature.id.fqn}" belongs to the protected namespace "{feature.id.namespace}". '
+                f'Feature namespaces cannot begin with "_chalk" or "__". Please rename this feature set.'
+            ),
         )
 
 
@@ -242,14 +254,14 @@ _BUILT_IN_SUPPORTED_TYPES = {
     "__pydantic__",
 }
 
+MissingMetadata = Dict[GraphLogSeverity, List[str]]
+
 
 def _validate_feature_metadata(
     features: List[UpsertFeatureGQL],
     builder: _LogBuilder,
     request_config: ProjectSettingsGQL,
 ):
-    MissingMetadata = NewType("MissingMetadata", Dict[GraphLogSeverity, List[str]])
-
     class WrappedFeature:
         def __init__(self, feature: UpsertFeatureGQL, missing_metadata: MissingMetadata):
             self.feature = feature
@@ -257,7 +269,15 @@ def _validate_feature_metadata(
 
     def get_missing_metadata(feature: UpsertFeatureGQL) -> MissingMetadata:
         res: MissingMetadata = collections.defaultdict(list)
-        for setting in request_config.validation.feature.metadata:
+        if (
+            request_config.validation
+            and request_config.validation.feature
+            and request_config.validation.feature.metadata
+        ):
+            settings = request_config.validation.feature.metadata
+        else:
+            settings = []
+        for setting in settings:
             metadata_name = setting.name
             severity = GraphLogSeverity(setting.missing.upper())
             if hasattr(feature, metadata_name):
@@ -310,7 +330,7 @@ def _validate_feature_metadata(
             header, subheader = get_missing_metadata_log(
                 wrapped_features=wrapped_features, severity=GraphLogSeverity(severity)
             )
-            if header is None:
+            if header is None or subheader is None:
                 continue
             builder.add_log(header=header, subheader=subheader, severity=GraphLogSeverity(severity))
 
@@ -338,7 +358,7 @@ def _validate_feature_metadata(
     for f in features:
         namespace_to_features[f.id.namespace].append(f)
 
-    for namespace, ns_features in namespace_to_features.items():
+    for ns_features in namespace_to_features.values():
         wf = get_wrapped_features(namespace_features=ns_features)
         build_log_for_each_severity(wrapped_features=wf)
 
