@@ -1,12 +1,12 @@
 from __future__ import annotations
 
 import types
-from typing import TYPE_CHECKING, List, Optional, Set, Type, TypeVar, Union, cast, get_type_hints
+import warnings
+from typing import TYPE_CHECKING, FrozenSet, List, Optional, Set, Tuple, Type, TypeVar, Union, cast
 
-from typing_extensions import Annotated, get_args, get_origin
+from typing_extensions import Annotated, get_args, get_origin, get_type_hints
 
 from chalk.utils.collection_type import GenericAlias
-from chalk.utils.metaprogramming import _MISSING_TYPE, MISSING
 
 if TYPE_CHECKING:
     from chalk.features import Features
@@ -32,8 +32,8 @@ class ParsedAnnotation:
         self._is_dataframe: Optional[bool] = None
         self._collection_type: Optional[GenericAlias] = None
         self._is_scalar: Optional[bool] = None
-        self._is_feature_time: Union[Optional[bool], _MISSING_TYPE] = MISSING
-        self._is_primary: Union[Optional[bool], _MISSING_TYPE] = MISSING
+        self._is_feature_time: Optional[bool] = None
+        self._is_primary: Optional[bool] = None
         self._underlying = None
         self._parsed_annotation = None
         if underlying is not None:
@@ -66,7 +66,7 @@ class ParsedAnnotation:
     def parsed_annotation(self) -> Union[type, Windowed]:
         """The parsed type annotation. It will be parsed if needed.
 
-        Unlike :attr:`underlying`, parsed annotation contains any container or optional types, such as
+        Unlike `.underlying`, parsed annotation contains any container or optional types, such as
         list, dataframe, or Optional.
         """
         if self._parsed_annotation is None:
@@ -82,7 +82,7 @@ class ParsedAnnotation:
     def _parse_annotation(self):
         assert self._features_cls is not None
         assert self._attribute_name is not None
-        hints = get_type_hints(self._features_cls)
+        hints = get_type_hints(self._features_cls, include_extras=True)
         parsed_annotation = hints[self._attribute_name]
         self._parse_type(parsed_annotation)
 
@@ -92,6 +92,8 @@ class ParsedAnnotation:
         assert self._parsed_annotation is None, "The annotation was already parsed"
         self._parsed_annotation = annotation
         self._is_nullable = False
+        self._is_primary = False
+        self._is_feature_time = False
         if self._features_cls is not None and self._attribute_name is not None:
             # Return a more helpful error message, since we have context
             error_ctx = f" {self._features_cls.__name__}.{self._attribute_name}"
@@ -99,6 +101,11 @@ class ParsedAnnotation:
             error_ctx = ""
         origin = get_origin(annotation)
         if origin is Annotated:
+            args = get_args(annotation)
+            if "__chalk_ts__" in args:
+                self._is_feature_time = True
+            if "__chalk_primary__" in args:
+                self._is_primary = True
             annotation = get_args(annotation)[0]
             origin = get_origin(annotation)
         if origin in (
@@ -112,6 +119,7 @@ class ParsedAnnotation:
                     f"Invalid annotation for feature{error_ctx}: Unions with non-None types are not allowed"
                 )
             annotation = args[0] if args[1] in (None, type(None)) else args[1]
+            origin = get_origin(annotation)
             self._is_nullable = True
 
         # The only allowed collections here are Set, List, or DataFrame
@@ -120,7 +128,16 @@ class ParsedAnnotation:
             assert len(args) == 1, "typing.Set takes just one arg"
             annotation = args[0]
             self._collection_type = Set[cast(Type, annotation)]
-
+        if origin in (frozenset, FrozenSet):
+            args = get_args(annotation)
+            assert len(args) == 1, "typing.FrozenSet takes just one arg"
+            annotation = args[0]
+            self._collection_type = FrozenSet[cast(Type, annotation)]
+        if origin in (tuple, Tuple):
+            args = get_args(annotation)
+            assert len(args) == 2 and args[1] is ..., "typing.Tuple is only supported if it is homogenous"
+            annotation = args[0]
+            self._collection_type = FrozenSet[cast(Type, annotation)]
         if origin in (list, List):
             args = get_args(annotation)
             assert len(args) == 1, "typing.List takes just one arg"
@@ -168,6 +185,12 @@ class ParsedAnnotation:
     @property
     def underlying(self) -> Union[type, Windowed]:
         """The underlying type annotation from the annotation."""
+        warnings.warn(
+            DeprecationWarning(
+                "`feature.typ.underlying` is deprecated. For scalar features, use `feature.converter.rich_type`. "
+                "For has-one features, use `feature.joined_class`."
+            )
+        )
         if self.parsed_annotation is None:
             self._parse_annotation()
         if self._underlying is None:
@@ -178,6 +201,35 @@ class ParsedAnnotation:
     def underlying(self, underlying: Optional[type]):
         self._underlying = underlying
 
+    @property
+    def is_windowed(self) -> bool:
+        from chalk.streams import Windowed
+
+        if self._parsed_annotation is None:
+            self._parse_annotation()
+        assert self._underlying is not None
+        return isinstance(self._underlying, Windowed)
+
+    @property
+    def is_features_cls(self) -> bool:
+        from chalk.features import Features
+
+        if self._parsed_annotation is None:
+            self._parse_annotation()
+        assert self._underlying is not None
+        return isinstance(self._underlying, type) and issubclass(self._underlying, Features)
+
+    @property
+    def as_features_cls(self) -> Type[Features]:
+        from chalk.features import Features
+
+        if self._parsed_annotation is None:
+            self._parse_annotation()
+        assert self._underlying is not None
+        if not (isinstance(self._underlying, type) and issubclass(self._underlying, Features)):
+            raise RuntimeError("The underlying is not a features class")
+        return self._underlying
+
     @property
     def is_dataframe(self) -> bool:
         """Whether the type annotation is a dataframe."""
@@ -188,6 +240,12 @@ class ParsedAnnotation:
 
     @property
     def collection_type(self) -> Optional[GenericAlias]:
+        warnings.warn(
+            DeprecationWarning(
+                "`feature.typ.collection_type` is deprecated. "
+                "Instead, convert to rich types via `feature.converter.from_XXX_to_rich` is a list"
+            )
+        )
         if self._parsed_annotation is None:
             self._parse_annotation()
         return self._collection_type
@@ -201,31 +259,15 @@ class ParsedAnnotation:
         return self._is_scalar
 
     @property
-    def is_primary(self) -> Optional[bool]:
-        if self._is_primary is not MISSING:
-            assert not isinstance(self._is_primary, _MISSING_TYPE)
-            return self._is_primary
-        self._is_primary = None
-        annotation = self.annotation
-        origin = get_origin(annotation)
-        if origin is not None:
-            args = get_args(annotation)
-            if "__chalk_primary__" in args:
-                self._is_primary = True
-
+    def is_primary(self) -> bool:
+        if self._parsed_annotation is None:
+            self._parse_annotation()
+        assert self._is_primary is not None
         return self._is_primary
 
     @property
-    def is_feature_time(self) -> Optional[bool]:
-        if self._is_feature_time is not MISSING:
-            assert not isinstance(self._is_feature_time, _MISSING_TYPE)
-            return self._is_feature_time
-        self._is_feature_time = None
-        annotation = self.annotation
-        origin = get_origin(annotation)
-        if origin is not None:
-            args = get_args(annotation)
-            if "__chalk_ts__" in args:
-                self._is_feature_time = True
-
+    def is_feature_time(self) -> bool:
+        if self._parsed_annotation is None:
+            self._parse_annotation()
+        assert self._is_feature_time is not None
         return self._is_feature_time
