@@ -111,7 +111,7 @@ class CommentDict(BaseModel):
             return [value]
         raise ValueError(f"Value {value} must be a string or a list of strings.")
 
-    @validator("cron", "max_staleness", "timeout")
+    @validator("max_staleness", "timeout")
     @classmethod
     def validate_timedelta(cls, string: Optional[str]):
         if string is None:
