@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Mapping, Optional, Union
+from typing import TYPE_CHECKING, Any, Literal, Mapping, Optional, Union
 
 from chalk.features import Feature
 from chalk.sql.finalized_query import FinalizedChalkQuery, Finalizer
@@ -77,7 +77,7 @@ class StringChalkQuery(StringChalkQueryProtocol):
         *,
         incremental_column: Optional[str] = None,
         lookback_period: Duration = "0s",
-        mode: str = "row",
+        mode: Literal["row", "group", "parameter"] = "row",
     ):
         if mode in {"row", "group"} and incremental_column is None:
             raise ValueError(f"incremental mode set to '{mode}' but no 'incremental_column' argument was passed.")
