@@ -25,6 +25,7 @@ __all__ = [
 
 P = ParamSpec("P")
 T = TypeVar("T")
+V = TypeVar("V")
 
 
 def stream(
@@ -35,6 +36,7 @@ def stream(
     machine_type: Optional[MachineType] = None,
     message: Optional[AnyDataclass] = None,
     owner: Optional[str] = None,
+    parse: Optional[Callable[[T], V]] = None,
 ) -> Callable[[Callable[P, T]], Callable[P, T]]:
     """Decorator to create a stream resolver.
 
@@ -75,6 +77,8 @@ def stream(
         Individual or team responsible for this resolver.
         The Chalk Dashboard will display this field, and alerts
         can be routed to owners.
+    parse
+        A callable that will interpret an input prior to the invocation of the resolver
 
     Other Parameters
     ----------------
@@ -109,6 +113,7 @@ def stream(
             machine_type=machine_type,
             message=message,
             owner=owner,
+            parse=parse,
         )
 
     return decorator
