@@ -1,42 +1,41 @@
 from __future__ import annotations
 
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Generic, List, Literal, Mapping, Optional, Set, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, Generic, List, Mapping, Optional, Set, Type, TypeVar, Union, cast
 
 from chalk._validation.feature_validation import FeatureValidation
+from chalk._validation.validation import Validation
 from chalk.features._encoding.primitive import TPrimitive
 from chalk.utils.collections import ensure_tuple
-from chalk.utils.duration import Duration, parse_chalk_duration, timedelta_to_duration
+from chalk.utils.duration import Duration, parse_chalk_duration
 
-T = TypeVar("T")
 TPrim = TypeVar("TPrim", bound=TPrimitive)
 TRich = TypeVar("TRich")
 
 if TYPE_CHECKING:
-    import polars as pl
+    import pyarrow as pa
 
     from chalk.features._encoding.converter import TDecoder, TEncoder
 
 
-class WindowedInstance(Generic[T]):
-    def __init__(self, values: Mapping[str, T]):
+class WindowedInstance(Generic[TRich]):
+    def __init__(self, values: Mapping[str, TRich]):
         self.values = values
 
     def __call__(self, period: str):
         return self.values[period]
 
 
-class WindowedMeta(type, Generic[T]):
-    def __getitem__(cls, underlying: Type[T]) -> "Windowed[Type[T]]":
+class WindowedMeta(type, Generic[TRich]):
+    def __getitem__(cls, underlying: Type[TRich]) -> Windowed[TRich]:
         return Windowed(
             kind=underlying,
             buckets=[],
-            mode="tumbling",
             description=None,
             owner=None,
             tags=None,
             name=None,
-            default=None,
+            default=...,
             max_staleness=None,
             version=None,
             etl_offline_to_online=None,
@@ -47,7 +46,10 @@ class WindowedMeta(type, Generic[T]):
             min_length=None,
             max_length=None,
             contains=None,
+            strict=False,
             dtype=None,
+            validations=None,
+            offline_ttl=None,
         )  # noqa
 
 
@@ -71,7 +73,13 @@ def get_name_with_duration(name_or_fqn: str, duration: Union[str, int, timedelta
     return f"{name_or_fqn}__{duration_secs}__"
 
 
-class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
+if TYPE_CHECKING:
+    _WINDOWED_METACLASS = type
+else:
+    _WINDOWED_METACLASS = WindowedMeta
+
+
+class Windowed(Generic[TRich], metaclass=_WINDOWED_METACLASS):
     """Declare a windowed feature.
 
     Examples
@@ -81,8 +89,6 @@ class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
     ...     failed_logins: Windowed[int] = windowed("10m", "24h")
     """
 
-    _mode: Literal["tumbling", "continuous"]
-
     @property
     def buckets_seconds(self) -> Set[int]:
         return set(int(parse_chalk_duration(bucket).total_seconds()) for bucket in self._buckets)
@@ -118,11 +124,8 @@ class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
             description=self._description,
             primary=False,
             default=self._default,
-            max_staleness=(
-                timedelta_to_duration(self._max_staleness)
-                if isinstance(self._max_staleness, timedelta)
-                else self._max_staleness
-            ),
+            max_staleness=self._max_staleness,
+            offline_ttl=self._offline_ttl,
             etl_offline_to_online=self._etl_offline_to_online,
             encoder=self._encoder,
             decoder=self._decoder,
@@ -133,25 +136,37 @@ class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
                 min_length=self._min_length,
                 max_length=self._max_length,
                 contains=self._contains,
+                strict=self._strict,
             ),
+            all_validations=None
+            if self._validations is None
+            else [
+                FeatureValidation(
+                    min=v.min,
+                    max=v.max,
+                    min_length=v.min_length,
+                    max_length=v.max_length,
+                    contains=None,
+                    strict=v.strict,
+                )
+                for v in self._validations
+            ],
             # Only the root feature should have all the durations
             # The pseudofeatures, which are bound to a duration, should not have the durations
             # of the other buckets
             window_durations=tuple(self.buckets_seconds) if bucket is None else tuple(),
             window_duration=None if bucket is None else get_duration_secs(bucket),
-            window_mode=self._mode,
         )
 
     def __init__(
         self,
         buckets: List[str],
-        mode: Literal["tumbling", "continuous"],
         description: Optional[str],
         owner: Optional[str],
         tags: Optional[Any],
         name: Optional[str],
         default: Union[TRich, ellipsis],
-        max_staleness: Union[Duration, None, ellipsis],
+        max_staleness: Optional[Union[Duration, ellipsis]],
         version: Optional[int],
         etl_offline_to_online: Optional[bool],
         encoder: Optional[TEncoder[TPrim, TRich]],
@@ -161,19 +176,22 @@ class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
         min_length: Optional[int],
         max_length: Optional[int],
         contains: Optional[TRich],
-        dtype: Optional[Union[Type[pl.DataType], pl.DataType]],
+        strict: bool,
+        validations: Optional[List[Validation]],
+        dtype: Optional[pa.DataType],
         kind: Optional[Type[TRich]],
+        offline_ttl: Optional[Union[Duration, ellipsis]],
     ):
         self._kind = kind
         self._name: Optional[str] = None
         self._buckets = buckets
-        self._mode = mode
         self._description = description
         self._owner = owner
         self._tags = tags
         self._name = name
         self._default = default
         self._max_staleness = max_staleness
+        self._offline_ttl = offline_ttl
         self._description = description
         self._version = version
         self._etl_offline_to_online = etl_offline_to_online
@@ -184,6 +202,8 @@ class Windowed(Generic[TPrim, TRich], metaclass=WindowedMeta):
         self._min_length = min_length
         self._max_length = max_length
         self._contains = contains
+        self._strict = strict
+        self._validations = validations
         self._dtype = dtype
 
 
@@ -199,21 +219,21 @@ def windowed(
     owner: Optional[str] = None,
     tags: Optional[Any] = None,
     name: Optional[str] = None,
-    default: Union[T, None, ellipsis] = ...,
-    max_staleness: Union[Duration, None, ellipsis] = ...,
+    default: Union[TRich, ellipsis] = ...,
+    max_staleness: Optional[Union[Duration, ellipsis]] = ...,
+    offline_ttl: Optional[Union[Duration, ellipsis]] = ...,
     version: Optional[int] = None,
     etl_offline_to_online: Optional[bool] = None,
     encoder: Optional[TEncoder[TPrim, TRich]] = None,
     decoder: Optional[TDecoder[TPrim, TRich]] = None,
-    min: Optional[T] = None,
-    max: Optional[T] = None,
+    min: Optional[TRich] = None,
+    max: Optional[TRich] = None,
     min_length: Optional[int] = None,
     max_length: Optional[int] = None,
-    contains: Optional[T] = None,
-    dtype: Optional[Union[Type[pl.DataType], pl.DataType]] = None,
-    # Deprecated
-    mode: Literal["tumbling", "continuous"] = "tumbling",
-) -> Windowed[TPrim, TRich]:
+    strict: bool = False,
+    validations: Optional[List[Validation]] = None,
+    dtype: Optional[pa.DataType] = None,
+) -> Windowed[TRich]:
     """Create a windowed feature.
 
     See more at https://docs.chalk.ai/docs/aggregations#windowed-features
@@ -260,7 +280,11 @@ def windowed(
         If specified, when this feature is computed, Chalk will check that `len(x) >= min_length`.
     max_length
         If specified, when this feature is computed, Chalk will check that `len(x) <= max_length`.
-    contains
+    strict
+        If `True`, if this feature does not meet the validation criteria, Chalk will not persist
+        the feature value and will treat it as failed.
+    validations
+    offline_ttl
 
     Other Parameters
     ----------------
@@ -290,7 +314,6 @@ def windowed(
     encoder
     decoder
     dtype
-    mode
 
     Returns
     -------
@@ -301,7 +324,6 @@ def windowed(
     """
     return Windowed(
         list(buckets),
-        mode=mode,
         description=description,
         owner=owner,
         tags=tags,
@@ -316,7 +338,10 @@ def windowed(
         max=max,
         min_length=min_length,
         max_length=max_length,
-        contains=contains,
+        contains=None,
+        strict=strict,
         dtype=dtype,
         kind=None,
+        validations=validations,
+        offline_ttl=offline_ttl,
     )
