@@ -166,3 +166,14 @@ def get_unique_item(collection: Iterable[Optional[T]], name: Optional[str] = Non
     if item is None:
         raise ValueError(f"There should be at least one item{in_name}")
     return item
+
+
+def get_unique_item_or_none(iterable: Iterable[Optional[T]]) -> Optional[T]:
+    item = None
+    for x in iterable:
+        if x is None:
+            continue
+        if item is not None:
+            raise ValueError(f"Multiple values not permitted. Found {item}, {x}")
+        item = x
+    return item
