@@ -33,11 +33,12 @@ def get_logging_context() -> Mapping[str, Any]:
 
 
 def set_logging_context(_merge: bool = True, **extra: Any):
-    """
-    Sets the context-local log context to a new value.
+    """Sets the context-local log context to a new value.
 
-    Args:
-        _merge: If true, the new context will be merged with the current context. Otherwise, the new context will overwrite the existing context.
+    Parameters
+    ----------
+    _merge
+        If True, the new context will be merged with the current context. Otherwise, the new context will overwrite the existing context.
     """
     log_context_stack = _LOGGING_CONTEXT_STACK.get([{}])
     if _merge:
@@ -52,8 +53,10 @@ def set_logging_context(_merge: bool = True, **extra: Any):
 def pop_logging_context():
     """Pop the latest log context off of the log context stack, and reset it to its previous value.
 
-    Raises:
-        RuntimeError, if there is no current context from set_logging_context()
+    Raises
+    ------
+    RuntimeError
+        If there is no current context from set_logging_context()
     """
     stack = _LOGGING_CONTEXT_STACK.get([])
     if len(stack) == 0:
@@ -90,12 +93,14 @@ Logger = get_logger
 
 @contextlib.contextmanager
 def add_logging_context(_merge: bool = True, **extra: Any):
-    """
-    A context manager to push and pop "extra" dictionary keys.
+    """A context manager to push and pop `extra` dictionary keys.
 
-    Args:
-        _merge: Whether to merge the new context with the existing log context.
-        extra: Contextual information to add to the log record
+    Parameters
+    ----------
+    _merge
+        Whether to merge the new context with the existing log context.
+    extra
+        Contextual information to add to the log record
     """
     set_logging_context(_merge, **extra)
     try:
