@@ -352,10 +352,11 @@ def features(item: Type[{features_cls_name}Protocol]) -> Type[{features_cls_name
 @overload
 def features(
     *,
-    owner: Optional[str] = ...,
-    tags: Optional[Tags] = ...,
+    owner: Optional[str] = None,
+    tags: Optional[Tags] = None,
+    etl_offline_to_online: bool = ...,
     max_staleness: Optional[Duration] = ...,
-    etl_offline_to_online: Optional[bool] = ...,
+    name: Optional[str] = None,
 ) -> __stubgen__features_proto: ...
 
 class __stubgen__features_proto(Protocol):"""
